transip
    * ``auth_username`` Specify username for authentication

    * ``auth_api_key`` Specify the private key to use for api authentication, in pem format: can be either the path of the key file (eg. /tmp/key.pem) or the base64 encoded content of this file prefixed by 'base64::' (eg. base64::eyjhbgcioyj...)

    * ``auth_key_is_global`` Set this flag is the private key used is a global key with no ip whitelist restriction
